# Troubleshooting assistance
- https://packaging.python.org/en/latest/tutorials/packaging-projects/
- https://twine.readthedocs.io/en/stable/

# Adding scripts in pyproject.toml
- https://packaging.python.org/en/latest/guides/writing-pyproject-toml/#creating-executable-scripts

# Pre-release tagging guide
- https://packaging.python.org/en/latest/guides/distributing-packages-using-setuptools/#choosing-a-versioning-scheme

